@@ -30,21 +30,22 @@ from time import perf_counter
 R = np.array([[1.0, 2.0, 0.0], [-8.0, 3.0, 2.0], [0.0, 1.0, 1.0]])
 s = np.array([3.0, 2.0, 3.0])
 G = np.array([[1.0, 2.0, 1.0], [2.0, 0.0, 1.0], [-1.0, 2.0, -1.0]])
-h = np.array([3.0, 2.0, -2.0]).reshape((3,))
+h = np.array([3.0, 2.0, -2.0])
 
-start_time = perf_counter()
-solver = "quadprog"  # see qpsolvers.available_solvers
-x = solve_ls(R, s, G, h, solver=solver, verbose=True)
-end_time = perf_counter()
+if __name__ == "__main__":
+    start_time = perf_counter()
+    solver = "quadprog"  # see qpsolvers.available_solvers
+    x = solve_ls(R, s, G, h, solver=solver, verbose=True)
+    end_time = perf_counter()
 
-print("")
-print("    min. || R * x - s ||^2")
-print("    s.t. G * x <= h")
-print("")
-print_matrix_vector(R, "R", s, "s")
-print("")
-print_matrix_vector(G, "G", h, "h")
-print("")
-print(f"Solution: x = {x}")
-print(f"Solve time: {1e6 * (end_time - start_time):.0f} [us]")
-print(f"Solver: {solver}")
+    print("")
+    print("    min. || R * x - s ||^2")
+    print("    s.t. G * x <= h")
+    print("")
+    print_matrix_vector(R, "R", s, "s")
+    print("")
+    print_matrix_vector(G, "G", h, "h")
+    print("")
+    print(f"Solution: x = {x}")
+    print(f"Solve time: {1e6 * (end_time - start_time):.0f} [us]")
+    print(f"Solver: {solver}")
