@@ -29,28 +29,29 @@ from time import perf_counter
 
 M = np.array([[1.0, 2.0, 0.0], [-8.0, 3.0, 2.0], [0.0, 1.0, 1.0]])
 P = np.dot(M.T, M)  # this is a positive definite matrix
-q = np.dot(np.array([3.0, 2.0, 3.0]), M).reshape((3,))
+q = np.dot(np.array([3.0, 2.0, 3.0]), M)
 G = np.array([[1.0, 2.0, 1.0], [2.0, 0.0, 1.0], [-1.0, 2.0, -1.0]])
-h = np.array([3.0, 2.0, -2.0]).reshape((3,))
+h = np.array([3.0, 2.0, -2.0])
 A = np.array([1.0, 1.0, 1.0])
 b = np.array([1.0])
 
-start_time = perf_counter()
-solver = "quadprog"  # see qpsolvers.available_solvers
-x = solve_qp(P, q, G, h, A, b, solver=solver)
-end_time = perf_counter()
+if __name__ == "__main__":
+    start_time = perf_counter()
+    solver = "quadprog"  # see qpsolvers.available_solvers
+    x = solve_qp(P, q, G, h, A, b, solver=solver)
+    end_time = perf_counter()
 
-print("")
-print("    min. 1/2 x^T P x + q^T x")
-print("    s.t. G * x <= h")
-print("         A * x == b")
-print("")
-print_matrix_vector(P, "P", q, "q")
-print("")
-print_matrix_vector(G, "G", h, "h")
-print("")
-print_matrix_vector(A, "A", b, "b")
-print("")
-print(f"Solution: x = {x}")
-print(f"Solve time: {1e6 * (end_time - start_time):.0f} [us]")
-print(f"Solver: {solver}")
+    print("")
+    print("    min. 1/2 x^T P x + q^T x")
+    print("    s.t. G * x <= h")
+    print("         A * x == b")
+    print("")
+    print_matrix_vector(P, "P", q, "q")
+    print("")
+    print_matrix_vector(G, "G", h, "h")
+    print("")
+    print_matrix_vector(A, "A", b, "b")
+    print("")
+    print(f"Solution: x = {x}")
+    print(f"Solve time: {1e6 * (end_time - start_time):.0f} [us]")
+    print(f"Solver: {solver}")
