@@ -35,11 +35,25 @@ from qpsolvers import available_solvers, sparse_solvers
 from qpsolvers import solve_qp, solve_safer_qp
 from qpsolvers.exceptions import SolverNotFound
 
+# Raising a ValueError when the problem is unbounded below is desired but not
+# achieved by some solvers. Here are the behaviors observed as of March 2022.
+# Unit tests only cover solvers that raise successfully:
+behavior_on_unbounded = {
+    "raise_value_error": ["cvxopt", "ecos", "quadprog", "scs"],
+    "return_crazy_solution": ["qpoases"],
+    "return_none": ["cvxpy", "osqp"],
+}
+
 
 class TestSolveQP(unittest.TestCase):
 
     """
-    Test fixture for the README example problem.
+    Test fixture for a variety of quadratic programs.
+
+    Solver-specific tests are implemented in static methods called
+    ``get_test_{foo}`` that return the test function for a given solver. The
+    corresponding test function ``test_{foo}_{solver}`` is then added to the
+    fixture below the class definition.
     """
 
     def setUp(self):
@@ -103,6 +117,14 @@ class TestSolveQP(unittest.TestCase):
         h = -2.0 * ones((n,))
         return P, q, G, h
 
+    def test_solver_not_found(self):
+        """
+        Check that SolverNotFound is raised when the solver does not exist.
+        """
+        P, q, G, h, A, b = self.get_dense_problem()
+        with self.assertRaises(SolverNotFound):
+            solve_qp(P, q, G, h, A, b, solver="ideal")
+
     @staticmethod
     def get_test(solver):
         """
@@ -330,8 +352,11 @@ class TestSolveQP(unittest.TestCase):
             self.assertIsNotNone(x)
             known_solution = array([0.30769231, -0.69230769, 1.38461538])
             sol_tolerance = (
-                1e-5 if solver == "scs" else
-                1e-6 if solver in ["cvxopt", "ecos"] else 1e-8
+                1e-5
+                if solver == "scs"
+                else 1e-6
+                if solver in ["cvxopt", "ecos"]
+                else 1e-8
             )
             ineq_tolerance = 1e-7 if solver == "scs" else 1e-8
             self.assertLess(norm(x - known_solution), sol_tolerance)
@@ -425,7 +450,13 @@ class TestSolveQP(unittest.TestCase):
             x = solve_qp(P, q, G, h, lb=lb, ub=ub, solver=solver)
             self.assertIsNotNone(x)
             known_solution = array([2.2] * 149 + [2.4])
-            sol_tolerance = 1e-3 if solver == "gurobi" else 1e-8
+            sol_tolerance = (
+                1e-3
+                if solver == "gurobi"
+                else 1e-7
+                if solver == "scs"
+                else 1e-8
+            )
             ineq_tolerance = 1e-10
             self.assertLess(norm(x - known_solution), sol_tolerance)
             self.assertLess(max(G * x - h), ineq_tolerance)
@@ -498,73 +529,106 @@ class TestSolveQP(unittest.TestCase):
 
         return test
 
-    def test_solver_not_found(self):
-        P, q, G, h, A, b = self.get_dense_problem()
-        with self.assertRaises(SolverNotFound):
-            solve_qp(P, q, G, h, A, b, solver="ideal")
+    @staticmethod
+    def get_test_raise_on_unbounded_below(solver):
+        """
+        Check that a ValueError is raised when the problem is unbounded below.
+
+        Parameters
+        ----------
+        solver : string
+            Name of the solver to test.
+
+        Returns
+        -------
+        test : function
+            Test function for that solver.
+
+        Notes
+        -----
+        Detecting non-convexity is not a trivial problem and most solvers leave
+        it to the user. See for instance the `recommendation from OSQP
+        <https://osqp.org/docs/interfaces/status_values.html#status-values>`_.
+        We only run this test for functions that successfully detect unbounded
+        problems when the eigenvalues of :math:`P` are close to zero.
+        """
+
+        def test(self):
+            v = array([5.4, -1.2, -1e-2, 1e4])
+            P = dot(v.reshape(4, 1), v.reshape(1, 4))
+            q = array([-1.0, -2, 0, 3e-4])
+            # q is in the nullspace of P, so the problem is unbounded below
+            with self.assertRaises(ValueError):
+                solve_qp(P, q, solver=solver)
+
+        return test
 
 
 # Generate test fixtures for each solver
 for solver in available_solvers:
-    setattr(
-        TestSolveQP, "test_{}".format(solver), TestSolveQP.get_test(solver)
-    )
+    setattr(TestSolveQP, f"test_{solver}", TestSolveQP.get_test(solver))
     setattr(
         TestSolveQP,
-        "test_all_shapes_{}".format(solver),
+        f"test_all_shapes_{solver}",
         TestSolveQP.get_test_all_shapes(solver),
     )
     setattr(
         TestSolveQP,
-        "test_bounds_{}".format(solver),
+        f"test_bounds_{solver}",
         TestSolveQP.get_test_bounds(solver),
     )
     setattr(
         TestSolveQP,
-        "test_no_cons_{}".format(solver),
+        f"test_no_cons_{solver}",
         TestSolveQP.get_test_no_cons(solver),
     )
     setattr(
         TestSolveQP,
-        "test_no_eq_{}".format(solver),
+        f"test_no_eq_{solver}",
         TestSolveQP.get_test_no_eq(solver),
     )
     setattr(
         TestSolveQP,
-        "test_no_ineq_{}".format(solver),
+        f"test_no_ineq_{solver}",
         TestSolveQP.get_test_no_ineq(solver),
     )
     setattr(
         TestSolveQP,
-        "test_one_ineq_{}".format(solver),
+        f"test_one_ineq_{solver}",
         TestSolveQP.get_test_one_ineq(solver),
     )
     setattr(
         TestSolveQP,
-        "test_safer_{}".format(solver),
+        f"test_safer_{solver}",
         TestSolveQP.get_test_safer(solver),
     )
     if solver in sparse_solvers:
         setattr(
             TestSolveQP,
-            "test_sparse_{}".format(solver),
+            f"test_sparse_{solver}",
             TestSolveQP.get_test_sparse(solver),
         )
         setattr(
             TestSolveQP,
-            "test_sparse_bounds_{}".format(solver),
+            f"test_sparse_bounds_{solver}",
             TestSolveQP.get_test_sparse_bounds(solver),
         )
         setattr(
             TestSolveQP,
-            "test_sparse_unfeasible_{}".format(solver),
+            f"test_sparse_unfeasible_{solver}",
             TestSolveQP.get_test_sparse_unfeasible(solver),
         )
     setattr(
         TestSolveQP,
-        "test_warmstart_{}".format(solver),
+        f"test_warmstart_{solver}",
         TestSolveQP.get_test_warmstart(solver),
     )
+    if solver in behavior_on_unbounded["raise_value_error"]:
+        setattr(
+            TestSolveQP,
+            f"test_raise_on_unbounded_below_{solver}",
+            TestSolveQP.get_test_raise_on_unbounded_below(solver),
+        )
 
 
 if __name__ == "__main__":
